Configuration API

Use the configuration API to operate on LoadLeveler configuration files.

This API consists of the following subroutines:

*  ll_config subroutine
*  ll_config_changed subroutine
*  ll_read_config subroutine



ll_config subroutine

Use the ll_config subroutine to manage LoadLeveler's configuration
database. This subroutine provides options to display or change the
value of the LoadLeveler keywords when the database option is being
used.


Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)


Syntax

  
#include llapi.h
enum LL_config_op { CONFIG_I, CONFIG_C, CONFIG_D };

    Note: The enum CONFIG_I is reserved for LoadLeveler internal use. 

int ll_config (int version, enum LL_config_op config_op, char **input,
               char ***output, char **hostlist,
               LL_element **err_obj);


Parameters

version
   Specifies the version of this API.

config_op
   Specifies the operation type: 

   CONFIG_C Changes the value of the specified keywords relating to
            machines.

   CONFIG_D Displays the value of the specified keywords relating to
            machines.

input
   A NULL-terminated char* array of input that depends on config_op. 

   CONFIG_C The elements of the array are strings in a format similar to
            keyword =value. They are used to change the value of any
            configuration keywords relating to machines. Keywords
            related to user, group, class, machine_group, and cluster
            cannot be changed using this command.

   CONFIG_D Each element of the array is one keyword whose value is to
            be displayed. This option shows the value of any
            configuration keywords relating to machines. Keywords
            related to user, group, class, machine_group, and cluster
            cannot be displayed using this option.

output
   A NULL-terminated char* array for CONFIG_D only. Each element of the
   array is a string in a format similar to keyword =value and each
   string corresponds to one keyword in input. It is the caller's
   responsibility to free the storage associated with this array.

hostlist
   A NULL-terminated char* array of host names.

errObj
   Is the address of a pointer to a LoadLeveler error object. The
   pointer to the LL_element should be set to NULL before calling this
   function. If this function fails, the pointer will point to an error
   object. The error messages stored in the error object can be
   displayed through the ll_error function. The caller should free the
   error object storage before reusing the pointer. If this function
   fails with some keywords, but succeeds with others, the error
   messages for the failed keywords are stored in this object.


Description

This subroutine performs operations that are essentially equivalent to
that performed by the llconfig command with the -c or -d option.


Return Values

LLCONFIG_DB_CANNOT_CONNECT
         Cannot connect to the database.

LLCONFIG_CHECK_FAILED
         Configuration errors were found when checking the configuration
         files.

LLCONFIG_CHANGE_AUTH_FAILED
         The caller is not authorized to run this operation.

LLCONFIG_CHANGE_OK
         The values for all or some keywords were changed. It is
         possible that some keywords are not valid or that there is no
         related record in the database.

LLCONFIG_CHANGE_RECONFIG_ERROR
         The values for all or some keywords were changed, but the
         reconfiguration procedure cannot finish for some or all hosts.

LLCONFIG_NOT_VALID_INPUT
         An input parameter was specified that is not valid.

LLCONFIG_DISPLAY_OK
         The records for all or some keywords were found and displayed.

LLCONFIG_LOAD_ODBC_LIBRARY_FAILED 
         The unixODBC library cannot be loaded.

LLCONFIG_LOADLDB_NOT_CONFIG 
         The LoadLDB keyword is not specified in the master
         configuration file.

LLCONFIG_CONFIG_OPT_UNSUPPORTED
         A config_op was specified that is not valid.


Related Information

Commands: llconfig
