#!/bin/sh
# This script is used by xCAT to configure the LoadLeveler compute nodes
# when running with a database option.  The management server node should
# have already initialized the DB using the llconfig -i command prior to
# executing this script.

POSTSCRIPT_PATH="LoadL"

# Clean up any existing copies of the generated files in the postscripts directory
/bin/rm -rf ${POSTSCRIPT_PATH}/LoadL.cfg.compute.generated

echo "replacing MASTER variable with the value defined in the environment..."
cat ${POSTSCRIPT_PATH}/LoadL.cfg.compute | sed "s/MASTER/${MASTER}/g" >> ${POSTSCRIPT_PATH}/LoadL.cfg.compute.generated 

echo "Copying the LoadL.cfg file to /etc ... "
cp ${POSTSCRIPT_PATH}/LoadL.cfg.compute.generated /etc/LoadL.cfg
/bin/chmod 644 /etc/LoadL.cfg

USER=`cat /etc/LoadL.cfg | grep -i loadluserid | sed 's/ //g' | cut -d'=' -f2`
GROUP=`cat /etc/LoadL.cfg | grep -i loadlgroupid | sed 's/ //g' | cut -d'=' -f2`

# creating the log/spool/execute directories with the LoadLeveler
# user/group defined in LoadL.cfg. The directories are created with 
# the following permissions:
#	log 	775
#	spool 	700 
# 	execute	1777

DIR_CONFIG_FILE="${POSTSCRIPT_PATH}/ll_config_directories"

while read line
do
	eval "/bin/mkdir -p $line"
	eval "/bin/chmod 777 $line"
	eval "/bin/chown -R ${USER}:${GROUP} $line"

	KW=${line##*/}
	if [[ ${KW} == "log" ]] ; then 
		eval "/bin/chmod 775 $line"
	elif [[ ${KW} == "spool" ]] ; then 
		eval "/bin/chmod 700 $line"
	elif [[ ${KW} == "execute" ]] ; then 
		eval "/bin/chmod 1777 $line"
	else 
		echo "error processing line: $line"
		exit -1
	fi
done < ${DIR_CONFIG_FILE}

